@@ -3,7 +3,8 @@
 # SPDX-License-Identifier: Apache-2.0
 
 #Plot
-def plot3D(func, plotRange=[[-1,1],[-1,1]], outNames = ['fobj'], nbpts=30, parameters=()):
+def plot3D(func, plotRange=[[-1,1],[-1,1]], outNames = ['fobj'], nbpts=30,
+           parameters=()):
     import matplotlib.pyplot as plt
     from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
     from matplotlib import cm
